{% extends base %}
{% load staticfiles %}
{% load custom %}

{% block content %}

<h1>Welcome</h1>

{% if error %}
<div class="alert alert-danger">
  {{ error }}
</div>
{% endif %}

<p>Please log in.</p>

<form method="post">
    {% csrf_token %}
    <input type="hidden" name="create"/>
    <table>
        <tr>
            <td><label>Username</label></td>
            <td><input type="text" class="form-control" name="username"/></td>
        </tr>
        <tr>
            <td><label>Password</label></td>
            <td><input type="password" class="form-control" name="password"/></td>
        </tr>
    </table>
    <button type="submit" class="btn btn-primary">Submit</button>
</form>

<br/>

{% endblock %}
