{% load i18n %}
{% load date_extras %}

{% if logs %}
<div class="panel panel-default">
    <div class="panel-heading">{% trans 'logs_title' %}</div>
    <div class="panel-body">
        <table class="table">
            <thead>
            <th>{% trans 'logs_date' %}</th>
            <th>{% trans 'logs_user' %}</th>
            <th>{% trans 'logs_action' %}</th>
            </thead>
            {% for log in logs %}
            <tr onclick="goto('{% url 'django:log_update' log.id %}')">
                <td>{{ log.date|short_datetime }}</td>
                <td>{{ log.author }}</td>
                <td>{{ log.action }}</td>
            </tr>
            {% endfor %}
        </table>
    </div>
</div>
{% endif %}
