{% if navigate %}
<!-- Navigator inputs -->
<input type="hidden" id="filter_key" name="filter_key" value="{{filter_key}}"/>
<input type="hidden" id="search" name="search" value="{{search}}"/>
<input type="hidden" id="sort" name="sort" value="{{sort}}"/>
<input type="hidden" id="paginator_page" name="paginator_page" value="{{paginator_page}}"/>
<input type="hidden" id="paginator_size" name="paginator_size" value="{{paginator_size}}"/>
{% endif %}
